@@ -100,14 +100,12 @@ class StableDiffusionControlNetDepthGenerator:
 
                     controlnet_depth_prompt = gr.Textbox(
                         lines=1,
-                        value="Prompt",
                         label="Prompt",
                         placeholder="Prompt",
                     )
 
                     controlnet_depth_negative_prompt = gr.Textbox(
                         lines=1,
-                        value="Negative Prompt",
                         label="Negative Prompt",
                         placeholder="Negative Prompt",
                     )
