@@ -93,14 +93,12 @@ class StableDiffusionControlNetHEDGenerator:
                     )
                     controlnet_hed_prompt = gr.Textbox(
                         lines=1,
-                        value="Prompt",
                         label="Prompt",
                         placeholder="Prompt",
                     )
 
                     controlnet_hed_negative_prompt = gr.Textbox(
                         lines=1,
-                        value="Negative Prompt",
                         label="Negative Prompt",
                         placeholder="Negative Prompt",
                     )
