@@ -90,14 +90,12 @@ class StableDiffusionControlNetMLSDGenerator:
 
                     controlnet_mlsd_prompt = gr.Textbox(
                         lines=1,
-                        value="Prompt",
                         label="Prompt",
                         placeholder="Prompt",
                     )
 
                     controlnet_mlsd_negative_prompt = gr.Textbox(
                         lines=1,
-                        value="Negative Prompt",
                         label="Negative Prompt",
                         placeholder="Negative Prompt",
                     )
